@@ -15,5 +15,3 @@
 """
 Appium Python Client
 """
-from .saucetestcase import SauceTestCase
-from .saucetestcase import on_platforms
