@@ -14,19 +14,31 @@
 
 # pylint: disable=abstract-method
 
-from appium.webdriver.common.mobileby import MobileBy
+from typing import TYPE_CHECKING, List, TypeVar, Union
+
+from appium.common.logger import logger
+from appium.webdriver.common.appiumby import AppiumBy
 
 from .base_search_context import BaseSearchContext
 
+if TYPE_CHECKING:
+    from appium.webdriver.webelement import WebElement
+
+T = TypeVar('T', bound=Union[BaseSearchContext, 'CustomSearchContext'])
+
 
 class CustomSearchContext(BaseSearchContext):
     """Define search context for custom plugin"""
 
-    def find_element_by_custom(self, selector):
-        """Finds an element in conjunction with a custom element finding plugin
+    def find_element_by_custom(self: T, selector: str) -> 'WebElement':
+        """
+        deprecated:: 2.1.0
+            Please use 'find_element' with 'AppiumBy.CUSTOM' instead.
+
+        Finds an element in conjunction with a custom element finding plugin
 
         Args:
-            selector (str): a string of the form "module:selector", where "module" is
+            selector: a string of the form "module:selector", where "module" is
                 the shortcut name given in the customFindModules capability, and
                 "selector" is the string that will be passed to the custom element
                 finding plugin itself
@@ -35,15 +47,20 @@ class CustomSearchContext(BaseSearchContext):
             driver.find_element_by_custom("foo:bar")
 
         Returns:
-            `appium.webdriver.webelement.WebElement`
+            `appium.webdriver.webelement.WebElement`: The found element
 
-        # To enable auto completion in PyCharm(IDE)
-        :rtype: `appium.webdriver.webelement.WebElement`
         """
-        return self.find_element(by=MobileBy.CUSTOM, value=selector)
 
-    def find_elements_by_custom(self, selector):
-        """Finds elements in conjunction with a custom element finding plugin
+        logger.warning("[Deprecated] Please use 'find_element' with 'AppiumBy.CUSTOM' instead.")
+
+        return self.find_element(by=AppiumBy.CUSTOM, value=selector)
+
+    def find_elements_by_custom(self: T, selector: str) -> List['WebElement']:
+        """
+        deprecated:: 2.1.0
+            Please use 'find_elements' with 'AppiumBy.CUSTOM' instead.
+
+        Finds elements in conjunction with a custom element finding plugin
 
         Args:
             selector: a string of the form "module:selector", where "module" is
@@ -55,8 +72,9 @@ class CustomSearchContext(BaseSearchContext):
             driver.find_elements_by_custom("foo:bar")
 
         Returns:
-            :obj:`list` of :obj:`appium.webdriver.webelement.WebElement`
-
-        :rtype: list of `appium.webdriver.webelement.WebElement`
+            :obj:`list` of :obj:`appium.webdriver.webelement.WebElement`: The found elements
         """
-        return self.find_elements(by=MobileBy.CUSTOM, value=selector)
+
+        logger.warning("[Deprecated] Please use 'find_elements' with 'AppiumBy.CUSTOM' instead.")
+
+        return self.find_elements(by=AppiumBy.CUSTOM, value=selector)
